@@ -5,8 +5,7 @@ use warnings;
 use Carp qw/confess/;
 use Scalar::Util qw/blessed/;
 use File::Temp();
-use Data::Dumper;
-use Test::Builder::Util qw/try/;
+use Test::Builder::Util qw/try type_isa/;
 
 sub tmpdir { shift->{tmpdir} }
 sub pid    { shift->{pid}    }
@@ -26,10 +25,10 @@ sub handle {
     my $self = shift;
     my ($item) = @_;
 
-    return if $item && blessed($item) && $item->isa('Test::Builder::Result::Finish');
+    return if $item && blessed($item) && type_isa($item, 'Test::Builder::Result::Finish');
 
     confess "Did not get a valid Test::Builder::Result object! ($item)"
-        unless $item && blessed($item) && $item->isa('Test::Builder::Result');
+        unless $item && blessed($item) && type_isa($item, 'Test::Builder::Result');
 
     my $stream = Test::Builder::Stream->shared;
     return 0 if $$ == $stream->pid;
@@ -37,8 +36,9 @@ sub handle {
     # First write the file, then rename it so that it is not read before it is ready.
     my $name =  $self->tmpdir . "/$$-" . $id++;
     open(my $fh, '>', $name) || die "Could not create temp file";
+    require Data::Dumper;
     local $Data::Dumper::Indent = 0;
-    print $fh Dumper($item);
+    print $fh Data::Dumper::Dumper($item);
     close $fh;
     rename($name, "$name.ready") || die "Could not rename file";
 
