@@ -5,14 +5,14 @@ use warnings;
 use Carp qw/confess/;
 use Scalar::Util qw/blessed/;
 
-use Test::Builder::Util qw/new/;
+use Test::Builder::Util qw/new package_sub type_isa/;
 
 sub handle {
     my $self = shift;
     my ($item) = @_;
 
     confess "Handler did not get a valid Test::Builder::Result object! ($item)"
-        unless $item && blessed($item) && $item->isa('Test::Builder::Result');
+        unless $item && blessed($item) && type_isa($item, 'Test::Builder::Result');
 
     my $method = $item->type;
 
@@ -35,7 +35,7 @@ sub listen {
     my $caller = caller;
 
     my $tb = $params{tb};
-    $tb ||= $caller->can('TB_INSTANCE') ? $caller->TB_INSTANCE : undef;
+    $tb ||= package_sub($caller, 'TB_INSTANCE') ? $caller->TB_INSTANCE : undef;
 
     my $stream = delete $params{stream} || ($tb ? $tb->stream : undef) || Test::Builder::Stream->shared;
 
