@@ -5,7 +5,7 @@ use warnings;
 use Carp qw/confess croak/;
 use Scalar::Util qw/reftype blessed/;
 use Test::Builder::Threads;
-use Test::Builder::Util qw/accessors accessor atomic_deltas try protect/;
+use Test::Builder::Util qw/accessors accessor atomic_deltas try protect type_isa/;
 
 accessors qw/plan bailed_out/;
 atomic_deltas qw/tests_run tests_failed/;
@@ -81,8 +81,9 @@ sub new {
 sub follow_up {
     my $self = shift;
     my ($type, @action) = @_;
+
     croak "'$type' is not a result type"
-        unless $type && $type->isa('Test::Builder::Result');
+        unless $type && type_isa($type, 'Test::Builder::Result');
 
     if (@action) {
         my ($sub) = @action;
@@ -250,50 +251,35 @@ sub send {
     }
 
     for my $item (@$items) {
-        if ($item->isa('Test::Builder::Result::Plan')) {
+        if (type_isa($item, 'Test::Builder::Result::Plan')) {
             $self->plan($item);
         }
 
-        if ($item->isa('Test::Builder::Result::Bail')) {
+        if (type_isa($item, 'Test::Builder::Result::Bail')) {
             $self->bailed_out($item);
         }
 
+        if (type_isa($item, 'Test::Builder::Result::Ok')) {
+            $self->tests_run(1);
+            $self->tests_failed(1) unless $item->bool;
+        }
+
         for my $listener (values %{$self->_listeners}) {
             protect {
                 if (reftype $listener eq 'CODE') {
-                    $listener->($item)
+                    $listener->($item);
+                    if ($item->can('diag') && $item->diag) {
+                        $listener->($_) for grep {$_} @{$item->diag};
+                    }
                 }
                 else {
                     $listener->handle($item);
+                    if ($item->can('diag') && $item->diag) {
+                        $listener->handle($_) for grep {$_} @{$item->diag};
+                    }
                 }
             };
         }
-
-        if ($item->isa('Test::Builder::Result::Ok')) {
-            $self->tests_run(1);
-            $self->tests_failed(1) unless $item->bool;
-
-            unless($item->real_bool || ($item->skip && $item->todo)) {
-                my $msg = $item->in_todo ? "Failed (TODO)" : "Failed";
-                my $prefix = $ENV{HARNESS_ACTIVE} ? "\n" : "";
-
-                my ($file, $line) = @{$item->trace->{report}}{qw/file line/};
-
-                if(defined $item->name) {
-                    my $name = $item->name;
-                    $msg = qq[$prefix  $msg test '$name'\n  at $file line $line.\n];
-                }
-                else {
-                    $msg = qq[$prefix  $msg test at $file line $line.\n];
-                }
-
-                my $diag = Test::Builder::Result::Diag->new(
-                    message => $msg || "",
-                    map {($_ => $item->$_ || undef)} qw/trace pid depth in_todo source/,
-                );
-                $self->send($diag);
-            }
-        }
     }
 
     for my $item (@$items) {
